@@ -2,7 +2,7 @@
 Date         : 2022-10-25 15:44:41
 Author       : BDFD,bdfd2005@gmail.com
 Github       : https://github.com/bdfd
-LastEditTime : 2022-11-07 16:32:36
+LastEditTime : 2022-11-08 15:14:02
 LastEditors  : BDFD
 Description  : 
 FilePath     : \execdata\__init__.py
@@ -11,4 +11,4 @@ Copyright (c) 2022 by BDFD, All Rights Reserved.
 
 from execdata.templateproj import add_one
 from execdata.preprocess import encode, sep, split, strat_split
-from execdata.model_evaluate import model_evaluate, algo_accuracy
+from execdata.model_evaluate import model_evaluate, algo_accuracy, result_comparision
